@@ -29,7 +29,7 @@ pub struct RubyPlugin {
 impl RubyPlugin {
     pub fn new() -> Self {
         Self {
-            core: CorePlugin::new("ruby".into()),
+            core: CorePlugin::new(BackendArg::new("ruby", "ruby")),
         }
     }
 
