@@ -8,6 +8,7 @@ use xx::file;
 use crate::backend;
 use crate::backend::Backend;
 use crate::cli::args::BackendArg;
+use crate::runtime_symlinks::is_runtime_symlink;
 use crate::toolset::{ToolVersion, ToolVersionOptions};
 
 #[derive(Debug, Clone, Hash, PartialEq, Eq)]
@@ -128,11 +129,10 @@ impl ToolRequest {
     }
 
     pub fn is_installed(&self) -> bool {
-        // TODO: dispatch to backend
-        match self {
-            Self::System(_) => true,
-            _ => self.install_path().is_some_and(|p| p.exists()),
-        }
+        let backend = backend::get(self.backend());
+        let tv = ToolVersion::new(backend.as_ref(), self.clone(), self.version());
+
+        backend.is_version_installed(&tv, false)
     }
 
     pub fn install_path(&self) -> Option<PathBuf> {
@@ -160,7 +160,10 @@ impl ToolRequest {
             } => match file::ls(&backend.installs_path) {
                 Ok(installs) => installs
                     .iter()
-                    .find(|p| p.file_name().unwrap().to_string_lossy().starts_with(prefix))
+                    .find(|p| {
+                        !is_runtime_symlink(p)
+                            && p.file_name().unwrap().to_string_lossy().starts_with(prefix)
+                    })
                     .cloned(),
                 Err(_) => None,
             },
